==> activity-center-biz-1.0.2-20160701.054452-45-sources.jar: cn/com/duiba/activity/center/biz/service/quizz/QuizzOrdersStatusChangeService.java <==
package cn.com.duiba.activity.center.biz.service.quizz;

import cn.com.duiba.activity.center.api.dto.quizz.QuizzOrdersDto;
import cn.com.duiba.activity.center.biz.entity.quizz.QuizzOrdersEntity;

/**
 * Created by xuezhaoming on 16/6/8.
 */
public interface QuizzOrdersStatusChangeService {
	
	Integer insert(QuizzOrdersDto quizzOrdersDto, long id);
	
	QuizzOrdersDto find(Long consumerId, Long id);

    int updateExchangeStatusToFail(Long consumerId, long id, String error4admin, String error4developer,
                                   String error4consumer);

    /**
     * 修改订单领奖状态为过期失效
     */
    int updateExchangeStatusToOverdue(long id, long consumerId, String error4admin, String error4developer, String error4consumer);

    /**
     * 修改订单状态失败
     */
    int updateStatusToFail(Long consumerId, long id, String error4admin, String error4developer, String error4consumer);

    /**
     * 处理领奖
     */
    Integer doTakePrize(Long consumerId, Long id);

    /**
     * 领奖创建订单失败，回滚领奖
     */
    Integer rollbackTakePrize(Long consumerId, Long id);

    /**
     * 处理抽奖结果
     */
    Integer updateLotteryResult(Long consumerId, Long id, Long appItemId, Long itemId, Long prizeId, String prizeName,
                                String prizeType, String prizeFacePrice, Long couponId);

    /**
     * 福袋请求降级处理时更新订单为谢谢参与
     */
    Integer updateLotteryLuckResult(Long consumerId, Long id, Long appItemId, Long itemId, Long prizeId,
                                    String prizeName, String prizeType, String prizeFacePrice, Long couponId);
}

==> activity-center-biz-1.0.2-20160706.034119-56-sources.jar: cn/com/duiba/activity/center/biz/service/quizz/QuizzOrdersStatusChangeService.java <==
package cn.com.duiba.activity.center.biz.service.quizz;

import cn.com.duiba.activity.center.api.dto.quizz.QuizzOrdersDto;
import cn.com.duiba.activity.center.biz.entity.quizz.QuizzOrdersEntity;

/**
 * Created by xuezhaoming on 16/6/8.
 */
public interface QuizzOrdersStatusChangeService {
	
	Integer insert(QuizzOrdersDto quizzOrdersDto, long id);
	
	QuizzOrdersDto find(Long consumerId, Long id);

    int updateExchangeStatusToFail(Long consumerId, long id, String error4admin, String error4developer,
                                   String error4consumer);

    /**
     * 修改订单领奖状态为过期失效
     */
    int updateExchangeStatusToOverdue(long id, String error4admin, String error4developer, String error4consumer);

    /**
     * 修改订单状态失败
     */
    int updateStatusToFail(Long consumerId, long id, String error4admin, String error4developer, String error4consumer);

    /**
     * 处理领奖
     */
    Integer doTakePrize(Long consumerId, Long id);

    /**
     * 领奖创建订单失败，回滚领奖
     */
    Integer rollbackTakePrize(Long consumerId, Long id);

    /**
     * 处理抽奖结果
     */
    Integer updateLotteryResult(Long consumerId, Long id, Long appItemId, Long itemId, Long prizeId, String prizeName,
                                String prizeType, String prizeFacePrice, Long couponId);

    /**
     * 福袋请求降级处理时更新订单为谢谢参与
     */
    Integer updateLotteryLuckResult(Long consumerId, Long id, Long appItemId, Long itemId, Long prizeId,
                                    String prizeName, String prizeType, String prizeFacePrice, Long couponId);
}
